/*
DL2 Monitor: ./lib/dl2pa.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (dl2pa): Application and Library Interface
 *
 * -Packet Output Format: <tstamp><length><packet>
 *  <tstamp> 32-bit-value, timestamp of <packet> in network byte order. 
 *  <length> 16-bit-value, length of <packet> in network byte order.
 *  <packet> the data received from the packet socket.
 *  
 * -Protocol Analyzers:
 *  dl2_paraw, dl2_paether, ...
 * 
 * -Others
 *  str2uint16, str2uint16, ... 
 *
 * -Constants (DL2_*):
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History
 * 20020414  dl2pa_libinit() introduced.
 * 20020330  created from scratch
 * $Id: dl2pa.h,v 1.3 2002/05/01 20:19:30 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __DL2PA_H__
# define __DL2PA_H__
# include "lib/csyntax.h"

typedef struct Dl2_Frame {
  Doctet type, code;
  Octet *buffer;
  int length;
} Dl2_Frame;

extern void dl2pa_libinit(void);
extern int dl2_paraw(Dl2_Frame*,int);
extern int dl2_paether2(Dl2_Frame*,int);
extern int dl2_papppoe(Dl2_Frame*,int);
extern int dl2_palcp(Dl2_Frame*,int);
extern int dl2_papap(Dl2_Frame*,int);
extern int dl2_pachap(Dl2_Frame*,int);
extern int dl2_paipcp(Dl2_Frame*,int);
extern int dl2_paicmp(Dl2_Frame*,int);
extern int dl2_patcp(Dl2_Frame*,int);
extern int dl2_paudp(Dl2_Frame*,int);
extern int dl2_paip(Dl2_Frame*,int);

extern Octet  str2oct(const Octet*);
extern Doctet str2doct(const Octet*);
extern Qoctet str2qoct(const Octet*);

# endif /*__DL2PA_H__*/
